@@ -36,7 +36,7 @@ var volumeMounts = []corev1.VolumeMount{
 	},
 }
 
-func setEnvVar(name string, key string) corev1.EnvVar {
+func buildEnvVarFromConfigMap(name string, key string) corev1.EnvVar {
 	return corev1.EnvVar{
 		Name: name,
 		ValueFrom: &corev1.EnvVarSource{
@@ -50,6 +50,18 @@ func setEnvVar(name string, key string) corev1.EnvVar {
 	}
 }
 
+func buildEnvVar(name string, key string, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.EnvVar {
+	value := getMetal3DeploymentConfig(name, baremetalProvisioningConfig)
+	if value != nil {
+		return corev1.EnvVar{
+			Name:  name,
+			Value: *value,
+		}
+	} else {
+		return buildEnvVarFromConfigMap(name, key)
+	}
+}
+
 func setMariadbPassword() corev1.EnvVar {
 	return corev1.EnvVar{
 		Name: "MARIADB_PASSWORD",
@@ -98,9 +110,9 @@ func createMariadbPasswordSecret(client coreclientv1.SecretsGetter, config *Oper
 	return err
 }
 
-func newMetal3Deployment(config *OperatorConfig) *appsv1.Deployment {
+func newMetal3Deployment(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) *appsv1.Deployment {
 	replicas := int32(1)
-	template := newMetal3PodTemplateSpec(config)
+	template := newMetal3PodTemplateSpec(config, baremetalProvisioningConfig)
 
 	return &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
@@ -127,9 +139,9 @@ func newMetal3Deployment(config *OperatorConfig) *appsv1.Deployment {
 	}
 }
 
-func newMetal3PodTemplateSpec(config *OperatorConfig) *corev1.PodTemplateSpec {
-	initContainers := newMetal3InitContainers(config)
-	containers := newMetal3Containers(config)
+func newMetal3PodTemplateSpec(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) *corev1.PodTemplateSpec {
+	initContainers := newMetal3InitContainers(config, baremetalProvisioningConfig)
+	containers := newMetal3Containers(config, baremetalProvisioningConfig)
 	tolerations := []corev1.Toleration{
 		{
 			Key:    "node-role.kubernetes.io/master",
@@ -176,7 +188,7 @@ func newMetal3PodTemplateSpec(config *OperatorConfig) *corev1.PodTemplateSpec {
 	}
 }
 
-func newMetal3InitContainers(config *OperatorConfig) []corev1.Container {
+func newMetal3InitContainers(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) []corev1.Container {
 	initContainers := []corev1.Container{
 		{
 			Name:            "metal3-ipa-downloader",
@@ -187,17 +199,15 @@ func newMetal3InitContainers(config *OperatorConfig) []corev1.Container {
 				Privileged: pointer.BoolPtr(true),
 			},
 			VolumeMounts: volumeMounts,
-			Env: []corev1.EnvVar{
-				setEnvVar("CACHEURL", "cache_url"),
-			},
+			Env:          []corev1.EnvVar{},
 		},
 	}
-	initContainers = append(initContainers, createInitContainerMachineOsDownloader(config))
-	initContainers = append(initContainers, createInitContainerStaticIpSet(config))
+	initContainers = append(initContainers, createInitContainerMachineOsDownloader(config, baremetalProvisioningConfig))
+	initContainers = append(initContainers, createInitContainerStaticIpSet(config, baremetalProvisioningConfig))
 	return initContainers
 }
 
-func createInitContainerMachineOsDownloader(config *OperatorConfig) corev1.Container {
+func createInitContainerMachineOsDownloader(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 	initContainer := corev1.Container{
 		Name:            "metal3-machine-os-downloader",
 		Image:           config.BaremetalControllers.IronicMachineOsDownloader,
@@ -208,14 +218,13 @@ func createInitContainerMachineOsDownloader(config *OperatorConfig) corev1.Conta
 		},
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
-			setEnvVar("RHCOS_IMAGE_URL", "rhcos_image_url"),
-			setEnvVar("CACHEURL", "cache_url"),
+			buildEnvVar("RHCOS_IMAGE_URL", "rhcos_image_url", baremetalProvisioningConfig),
 		},
 	}
 	return initContainer
 }
 
-func createInitContainerStaticIpSet(config *OperatorConfig) corev1.Container {
+func createInitContainerStaticIpSet(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 	initContainer := corev1.Container{
 		Name:            "metal3-static-ip-set",
 		Image:           config.BaremetalControllers.IronicStaticIpManager,
@@ -225,14 +234,14 @@ func createInitContainerStaticIpSet(config *OperatorConfig) corev1.Container {
 			Privileged: pointer.BoolPtr(true),
 		},
 		Env: []corev1.EnvVar{
-			setEnvVar("PROVISIONING_IP", "provisioning_ip"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("PROVISIONING_IP", "provisioning_ip", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return initContainer
 }
 
-func newMetal3Containers(config *OperatorConfig) []corev1.Container {
+func newMetal3Containers(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) []corev1.Container {
 	//Starting off with the metal3-baremetal-operator container
 	containers := []corev1.Container{
 		{
@@ -267,24 +276,24 @@ func newMetal3Containers(config *OperatorConfig) []corev1.Container {
 					Name:  "OPERATOR_NAME",
 					Value: "baremetal-operator",
 				},
-				setEnvVar("DEPLOY_KERNEL_URL", "deploy_kernel_url"),
-				setEnvVar("DEPLOY_RAMDISK_URL", "deploy_ramdisk_url"),
-				setEnvVar("IRONIC_ENDPOINT", "ironic_endpoint"),
-				setEnvVar("IRONIC_INSPECTOR_ENDPOINT", "ironic_inspector_endpoint"),
+				buildEnvVar("DEPLOY_KERNEL_URL", "deploy_kernel_url", baremetalProvisioningConfig),
+				buildEnvVar("DEPLOY_RAMDISK_URL", "deploy_ramdisk_url", baremetalProvisioningConfig),
+				buildEnvVar("IRONIC_ENDPOINT", "ironic_endpoint", baremetalProvisioningConfig),
+				buildEnvVar("IRONIC_INSPECTOR_ENDPOINT", "ironic_inspector_endpoint", baremetalProvisioningConfig),
 			},
 		},
 	}
-	containers = append(containers, createContainerMetal3Dnsmasq(config))
+	containers = append(containers, createContainerMetal3Dnsmasq(config, baremetalProvisioningConfig))
 	containers = append(containers, createContainerMetal3Mariadb(config))
-	containers = append(containers, createContainerMetal3Httpd(config))
-	containers = append(containers, createContainerMetal3IronicConductor(config))
-	containers = append(containers, createContainerMetal3IronicApi(config))
-	containers = append(containers, createContainerMetal3IronicInspector(config))
-	containers = append(containers, createContainerMetal3StaticIpManager(config))
+	containers = append(containers, createContainerMetal3Httpd(config, baremetalProvisioningConfig))
+	containers = append(containers, createContainerMetal3IronicConductor(config, baremetalProvisioningConfig))
+	containers = append(containers, createContainerMetal3IronicApi(config, baremetalProvisioningConfig))
+	containers = append(containers, createContainerMetal3IronicInspector(config, baremetalProvisioningConfig))
+	containers = append(containers, createContainerMetal3StaticIpManager(config, baremetalProvisioningConfig))
 	return containers
 }
 
-func createContainerMetal3Dnsmasq(config *OperatorConfig) corev1.Container {
+func createContainerMetal3Dnsmasq(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-dnsmasq",
@@ -296,9 +305,9 @@ func createContainerMetal3Dnsmasq(config *OperatorConfig) corev1.Container {
 		Command:      []string{"/bin/rundnsmasq"},
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
-			setEnvVar("HTTP_PORT", "http_port"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
-			setEnvVar("DHCP_RANGE", "dhcp_range"),
+			buildEnvVar("HTTP_PORT", "http_port", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
+			buildEnvVar("DHCP_RANGE", "dhcp_range", baremetalProvisioningConfig),
 		},
 	}
 	return container
@@ -322,7 +331,7 @@ func createContainerMetal3Mariadb(config *OperatorConfig) corev1.Container {
 	return container
 }
 
-func createContainerMetal3Httpd(config *OperatorConfig) corev1.Container {
+func createContainerMetal3Httpd(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-httpd",
@@ -334,14 +343,14 @@ func createContainerMetal3Httpd(config *OperatorConfig) corev1.Container {
 		Command:      []string{"/bin/runhttpd"},
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
-			setEnvVar("HTTP_PORT", "http_port"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("HTTP_PORT", "http_port", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return container
 }
 
-func createContainerMetal3IronicConductor(config *OperatorConfig) corev1.Container {
+func createContainerMetal3IronicConductor(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-ironic-conductor",
@@ -354,14 +363,14 @@ func createContainerMetal3IronicConductor(config *OperatorConfig) corev1.Contain
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
 			setMariadbPassword(),
-			setEnvVar("HTTP_PORT", "http_port"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("HTTP_PORT", "http_port", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return container
 }
 
-func createContainerMetal3IronicApi(config *OperatorConfig) corev1.Container {
+func createContainerMetal3IronicApi(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-ironic-api",
@@ -374,14 +383,14 @@ func createContainerMetal3IronicApi(config *OperatorConfig) corev1.Container {
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
 			setMariadbPassword(),
-			setEnvVar("HTTP_PORT", "http_port"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("HTTP_PORT", "http_port", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return container
 }
 
-func createContainerMetal3IronicInspector(config *OperatorConfig) corev1.Container {
+func createContainerMetal3IronicInspector(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-ironic-inspector",
@@ -392,13 +401,13 @@ func createContainerMetal3IronicInspector(config *OperatorConfig) corev1.Contain
 		},
 		VolumeMounts: volumeMounts,
 		Env: []corev1.EnvVar{
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return container
 }
 
-func createContainerMetal3StaticIpManager(config *OperatorConfig) corev1.Container {
+func createContainerMetal3StaticIpManager(config *OperatorConfig, baremetalProvisioningConfig BaremetalProvisioningConfig) corev1.Container {
 
 	container := corev1.Container{
 		Name:            "metal3-static-ip-manager",
@@ -409,8 +418,8 @@ func createContainerMetal3StaticIpManager(config *OperatorConfig) corev1.Contain
 			Privileged: pointer.BoolPtr(true),
 		},
 		Env: []corev1.EnvVar{
-			setEnvVar("PROVISIONING_IP", "provisioning_ip"),
-			setEnvVar("PROVISIONING_INTERFACE", "provisioning_interface"),
+			buildEnvVar("PROVISIONING_IP", "provisioning_ip", baremetalProvisioningConfig),
+			buildEnvVar("PROVISIONING_INTERFACE", "provisioning_interface", baremetalProvisioningConfig),
 		},
 	}
 	return container
